Coverage for actress/__init__.py: 100%

1"""

2 An implementation of actor model of concurrency in Python.

3"""

4

5 from .task import (

6 Task,

7 Effect,

8 Controller,

9 Fork,

10 ControllerFork,

11 TaskFork,

12 Result,

13 Success,

14 Failure,

15 Control,

16 Instruction,

17 CURRENT,

18 SUSPEND,

19 current,

20 suspend,

21 sleep,

22 wait,

23 TaskGroup,

24 send,

25 effect,

26 main,

27 resume,

28 spawn,

29 fork,

30 join,

31 group,

32 abort,

33 exit_,

34 terminate,

35 all_,

36 then_,

37 none_,

38 listen,

39 tag,

40 batch,

41 effects,

42 loop,

43)

44 __all__ = [

45 "Task",

46 "Effect",

47 "Controller",

48 "Fork",

49 "ControllerFork",

50 "TaskFork",

51 "Control",

52 "Instruction",

53 "Result",

54 "Success",

55 "Failure",

56 "CURRENT",

57 "SUSPEND",

58 "current",

59 "suspend",

60 "sleep",

61 "wait",

62 "TaskGroup",

63 "send",

64 "effect",

65 "main",

66 "resume",

67 "spawn",

68 "fork",

69 "join",

70 "group",

71 "abort",

72 "exit_",

73 "terminate",

74 "all_",

75 "then_",

76 "none_",

77 "listen",

78 "tag",

79 "batch",

80 "effects",

81 "loop",

82]